PCB Environment: Namespace Members

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all namespace functions with links to the namespace documentation for each function:

### - _ -

- _capsuleDtor() : py

### - b -

- bbox_area() : geo
- bbox_diameter() : geo

### - c -

- CheckErrors() : GL
- closest_on() : geo
- ConnectionLinkage() : metrics
- cosine() : geo
- cropBox() : geo

### - d -

- DECREF_safe() : py
- Dict_StealItem() : py
- Dict_StealItemString() : py
- distance45() : geo

### - e -

- Exception() : py
- expandBox() : geo
- expandBox_r() : geo

### - g -

- get_bounding_box() : dsn
- getContext() : GL

### - i -

- is1TrueYesOrPlus() : util

### - l -

- lexiconumeric_compare() : util
- loadFile() : util
- loadShaderPipeline() : helper

### - m -

- MemoryError() : py
- multiply() : math

### - n -

- NewRef() : py
- None() : py
- Number_AsDouble() : py

### - p -

- populate() : util

### - r -

- Radians() : math
- RatsNestCrossings() : metrics
- reduce_max() : math
- rsqrt() : math::approx

### - s -

- SegmentParallelity() : metrics
- squared() : math
- String() : py
- String_AsStdString() : py
- String_AsStringView() : py
- String_Check() : py

### - t -

- to_string() : geo
- tolower() : util
- TupleMin_Check() : py
- TupleN_Check() : py

### - v -

- ValueError() : py